@@ -118,7 +118,7 @@ class image_dehazer():
 
         # Cyclic loop for refining t and u --> Section III in the paper
         beta = 1  # Start Beta value --> selected from the paper
-        beta_max = 2 ** 8  # Selected from the paper --> Section III --> "Scene Transmission Estimation"
+        beta_max = 2 ** 4  # Selected from the paper --> Section III --> "Scene Transmission Estimation"
         beta_rate = 2 * np.sqrt(2)  # Selected from the paper
 
         while (beta < beta_max):
@@ -138,6 +138,10 @@ class image_dehazer():
             self._Transmission = np.abs(np.fft.ifft2((gamma * tF + DU) / (gamma + DS)))
             beta = beta * beta_rate
 
+        cv2.imshow("a", self._Transmission)
+        cv2.waitKey(0)
+        print('here')
+
     def __removeHaze(self, HazeImg):
         '''
         :param HazeImg: Hazy input image
